@@ -1,7 +1,7 @@
 # ABSTRACT: Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 package PONAPI::Client;
 
-our $VERSION = '0.002006';
+our $VERSION = '0.002007';
 
 use Moose;
 
@@ -124,20 +124,30 @@ sub _args {
     return %args;
 }
 
+sub _http_request {
+    $_[1]->{parse_chunked} = 1;
+    return Hijk::request($_[1]);
+}
+
 sub _send_ponapi_request {
     my $self = shift;
     my %args = @_;
 
+    my @mt_header = (
+        ( $args{body} ? 'Content-Type' : 'Accept' ),
+        'application/vnd.api+json'
+    );
+
     my ($status, $content, $failed, $e);
     ($status, $content) = do {
         local $@;
         eval {
-            my $res = Hijk::request({
+            my $res = $self->_http_request({
                 %args,
                 host => $self->host,
                 port => $self->port,
                 head => [
-                    'Content-Type' => 'application/vnd.api+json',
+                    @mt_header,
                     ( $self->send_version_header
                         ? ( 'X-PONAPI-Client-Version' => '1.0' )
                         : ()
@@ -147,7 +157,6 @@ sub _send_ponapi_request {
                         : ()
                     ),
                 ],
-                parse_chunked => 1,
             });
             $status  = $res->{status};
 
@@ -191,7 +200,7 @@ PONAPI::Client - Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 
 =head1 VERSION
 
-version 0.002006
+version 0.002007
 
 =head1 SYNOPSIS
 
